==> okta-sdk-api-20.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/AuthenticatorEnrollmentPolicyAuthenticatorSettingsEnroll.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.AuthenticatorEnrollmentPolicyAuthenticatorStatus;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Enrollment requirements for the authenticator
 */
@ApiModel(description = "Enrollment requirements for the authenticator")
@JsonPropertyOrder({ AuthenticatorEnrollmentPolicyAuthenticatorSettingsEnroll.JSON_PROPERTY_SELF })
@JsonTypeName("AuthenticatorEnrollmentPolicyAuthenticatorSettings_enroll")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class AuthenticatorEnrollmentPolicyAuthenticatorSettingsEnroll implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_SELF = "self";
    private AuthenticatorEnrollmentPolicyAuthenticatorStatus self = AuthenticatorEnrollmentPolicyAuthenticatorStatus.NOT_ALLOWED;

    public AuthenticatorEnrollmentPolicyAuthenticatorSettingsEnroll() {
    }

    public AuthenticatorEnrollmentPolicyAuthenticatorSettingsEnroll self(
            AuthenticatorEnrollmentPolicyAuthenticatorStatus self) {

        this.self = self;
        return this;
    }

    /**
     * Get self
     *
     * @return self
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public AuthenticatorEnrollmentPolicyAuthenticatorStatus getSelf() {
        return self;
    }

    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSelf(AuthenticatorEnrollmentPolicyAuthenticatorStatus self) {
        this.self = self;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        AuthenticatorEnrollmentPolicyAuthenticatorSettingsEnroll authenticatorEnrollmentPolicyAuthenticatorSettingsEnroll = (AuthenticatorEnrollmentPolicyAuthenticatorSettingsEnroll) o;
        return Objects.equals(this.self, authenticatorEnrollmentPolicyAuthenticatorSettingsEnroll.self);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(self);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class AuthenticatorEnrollmentPolicyAuthenticatorSettingsEnroll {\n");
        sb.append("    self: ").append(toIndentedString(self)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-24.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/AuthenticatorEnrollmentPolicyAuthenticatorSettingsEnroll.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.AuthenticatorEnrollmentPolicyAuthenticatorStatus;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Enrollment requirements for the authenticator
 */
@ApiModel(description = "Enrollment requirements for the authenticator")
@JsonPropertyOrder({ AuthenticatorEnrollmentPolicyAuthenticatorSettingsEnroll.JSON_PROPERTY_SELF })
@JsonTypeName("AuthenticatorEnrollmentPolicyAuthenticatorSettings_enroll")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-07-28T10:14:57.946459+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class AuthenticatorEnrollmentPolicyAuthenticatorSettingsEnroll implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_SELF = "self";
    private AuthenticatorEnrollmentPolicyAuthenticatorStatus self = AuthenticatorEnrollmentPolicyAuthenticatorStatus.NOT_ALLOWED;

    public AuthenticatorEnrollmentPolicyAuthenticatorSettingsEnroll() {
    }

    public AuthenticatorEnrollmentPolicyAuthenticatorSettingsEnroll self(
            AuthenticatorEnrollmentPolicyAuthenticatorStatus self) {

        this.self = self;
        return this;
    }

    /**
     * Get self
     *
     * @return self
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public AuthenticatorEnrollmentPolicyAuthenticatorStatus getSelf() {
        return self;
    }

    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSelf(AuthenticatorEnrollmentPolicyAuthenticatorStatus self) {
        this.self = self;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        AuthenticatorEnrollmentPolicyAuthenticatorSettingsEnroll authenticatorEnrollmentPolicyAuthenticatorSettingsEnroll = (AuthenticatorEnrollmentPolicyAuthenticatorSettingsEnroll) o;
        return Objects.equals(this.self, authenticatorEnrollmentPolicyAuthenticatorSettingsEnroll.self);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(self);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class AuthenticatorEnrollmentPolicyAuthenticatorSettingsEnroll {\n");
        sb.append("    self: ").append(toIndentedString(self)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
